==> sdd.banconnector.debin-api-server-1.1.14-sources.jar: ar/com/sdd/banconnector/debin/api/server/model/DebinAccount.java <==
package ar.com.sdd.banconnector.debin.api.server.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.io.Serializable;

@JsonIgnoreProperties(ignoreUnknown = true)
public class DebinAccount implements Serializable {

    private String id;
    private String cuit;
    private String unifiedBankReference;
    private String alias;
    private String description;
    private String bankCode;
    private String branchCode;
    private String currency;
    private DebinConst.DebinAccountStatusEnum status;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCuit() {
        return cuit;
    }

    public void setCuit(String cuit) {
        this.cuit = cuit;
    }

    public String getUnifiedBankReference() {
        return unifiedBankReference;
    }

    public void setUnifiedBankReference(String unifiedBankReference) {
        this.unifiedBankReference = unifiedBankReference;
    }

    public String getAlias() {
        return alias;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public String getBranchCode() {
        return branchCode;
    }

    public void setBranchCode(String branchCode) {
        this.branchCode = branchCode;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public DebinConst.DebinAccountStatusEnum getStatus() {
        return status;
    }

    public void setStatus(DebinConst.DebinAccountStatusEnum status) {
        this.status = status;
    }

    @Override
    public String toString() {
        return "DebinAccount ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((cuit != null) ? "cuit=" + cuit + ", " : "")
                + ((unifiedBankReference != null) ? "unifiedBankReference=" + unifiedBankReference + ", " : "")
                + ((alias != null) ? "alias=" + alias + ", " : "")
                + ((description != null) ? "description=" + description + ", " : "")
                + ((bankCode != null) ? "bankCode=" + bankCode + ", " : "")
                + ((branchCode != null) ? "branchCode=" + branchCode + ", " : "")
                + ((currency != null) ? "currency=" + currency + ", " : "")
                + ((status != null) ? "status=" + status : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        DebinAccount that = (DebinAccount) o;

        if (id != null ? !id.equals(that.id) : that.id != null) return false;
        if (cuit != null ? !cuit.equals(that.cuit) : that.cuit != null) return false;
        if (unifiedBankReference != null ? !unifiedBankReference.equals(that.unifiedBankReference) : that.unifiedBankReference != null) return false;
        if (alias != null ? !alias.equals(that.alias) : that.alias != null) return false;
        if (description != null ? !description.equals(that.description) : that.description != null) return false;
        if (bankCode != null ? !bankCode.equals(that.bankCode) : that.bankCode != null) return false;
        if (branchCode != null ? !branchCode.equals(that.branchCode) : that.branchCode != null) return false;
        if (currency != null ? !currency.equals(that.currency) : that.currency != null) return false;
        return status == that.status;
    }

    @Override
    public int hashCode() {
        int result = id != null ? id.hashCode() : 0;
        result = 31 * result + (cuit != null ? cuit.hashCode() : 0);
        result = 31 * result + (unifiedBankReference != null ? unifiedBankReference.hashCode() : 0);
        result = 31 * result + (alias != null ? alias.hashCode() : 0);
        result = 31 * result + (description != null ? description.hashCode() : 0);
        result = 31 * result + (bankCode != null ? bankCode.hashCode() : 0);
        result = 31 * result + (branchCode != null ? branchCode.hashCode() : 0);
        result = 31 * result + (currency != null ? currency.hashCode() : 0);
        result = 31 * result + (status != null ? status.hashCode() : 0);
        return result;
    }
}

==> sdd.banconnector.debin-api-server-1.2.2-sources.jar: ar/com/sdd/banconnector/debin/api/server/model/DebinAccount.java <==
package ar.com.sdd.banconnector.debin.api.server.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.io.Serializable;

@JsonIgnoreProperties(ignoreUnknown = true)
public class DebinAccount implements Serializable {

    private String id;
    private String cuit;
    private String unifiedBankReference;
    private String alias;
    private String description;
    private String bankCode;
    private String branchCode;
    private String currency;
    private DebinConst.DebinAccountStatusEnum status;
    private String email;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCuit() {
        return cuit;
    }

    public void setCuit(String cuit) {
        this.cuit = cuit;
    }

    public String getUnifiedBankReference() {
        return unifiedBankReference;
    }

    public void setUnifiedBankReference(String unifiedBankReference) {
        this.unifiedBankReference = unifiedBankReference;
    }

    public String getAlias() {
        return alias;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public String getBranchCode() {
        return branchCode;
    }

    public void setBranchCode(String branchCode) {
        this.branchCode = branchCode;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public DebinConst.DebinAccountStatusEnum getStatus() {
        return status;
    }

    public void setStatus(DebinConst.DebinAccountStatusEnum status) {
        this.status = status;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    @Override
    public String toString() {
        return "DebinAccount ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((cuit != null) ? "cuit=" + cuit + ", " : "")
                + ((unifiedBankReference != null) ? "unifiedBankReference=" + unifiedBankReference + ", " : "")
                + ((alias != null) ? "alias=" + alias + ", " : "")
                + ((description != null) ? "description=" + description + ", " : "")
                + ((bankCode != null) ? "bankCode=" + bankCode + ", " : "")
                + ((branchCode != null) ? "branchCode=" + branchCode + ", " : "")
                + ((currency != null) ? "currency=" + currency + ", " : "")
                + ((status != null) ? "status=" + status + ", " : "")
                + ((email != null) ? "email=" + email : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        DebinAccount that = (DebinAccount) o;

        if (id != null ? !id.equals(that.id) : that.id != null) return false;
        if (cuit != null ? !cuit.equals(that.cuit) : that.cuit != null) return false;
        if (unifiedBankReference != null ? !unifiedBankReference.equals(that.unifiedBankReference) : that.unifiedBankReference != null) return false;
        if (alias != null ? !alias.equals(that.alias) : that.alias != null) return false;
        if (description != null ? !description.equals(that.description) : that.description != null) return false;
        if (bankCode != null ? !bankCode.equals(that.bankCode) : that.bankCode != null) return false;
        if (branchCode != null ? !branchCode.equals(that.branchCode) : that.branchCode != null) return false;
        if (currency != null ? !currency.equals(that.currency) : that.currency != null) return false;
        if (status != that.status) return false;
        return email != null ? email.equals(that.email) : that.email == null;
    }

    @Override
    public int hashCode() {
        int result = id != null ? id.hashCode() : 0;
        result = 31 * result + (cuit != null ? cuit.hashCode() : 0);
        result = 31 * result + (unifiedBankReference != null ? unifiedBankReference.hashCode() : 0);
        result = 31 * result + (alias != null ? alias.hashCode() : 0);
        result = 31 * result + (description != null ? description.hashCode() : 0);
        result = 31 * result + (bankCode != null ? bankCode.hashCode() : 0);
        result = 31 * result + (branchCode != null ? branchCode.hashCode() : 0);
        result = 31 * result + (currency != null ? currency.hashCode() : 0);
        result = 31 * result + (status != null ? status.hashCode() : 0);
        result = 31 * result + (email != null ? email.hashCode() : 0);
        return result;
    }
}
